@@ -142,8 +142,8 @@ typedef enum {
  * structure is to use the GNOMEUIINFO_* macros provided below. */
 typedef struct {
 	GnomeUIInfoType type;		/* Type of item */
-	gchar *label;			/* String to use in the label */
-	gchar *hint;			/* For toolbar items, the tooltip. For 
+	gchar const *label;			/* String to use in the label */
+	gchar const *hint;			/* For toolbar items, the tooltip. For 
 					   menu items, the status bar message */
 	gpointer moreinfo;		/* For an item, toggleitem, or 
 					   radioitem, this is a pointer to the 
@@ -562,7 +562,10 @@ typedef void (* GnomeUISignalConnectFunc) (GnomeUIInfo        *uiinfo,
 struct _GnomeUIBuilderData {
 	GnomeUISignalConnectFunc connect_func;	/* Function that connects to the item's signals */
 	gpointer data;				/* User data pointer */
-	gboolean is_interp;			/* Should use gtk_signal_connect_interp or normal gtk_signal_connect? */
+	gboolean is_interp;			/* Should use
+						 * g_signal_connect_closure_by_id
+						 * or normal g_signal_connect?
+						 */
 	GtkCallbackMarshal relay_func;		/* Marshaller function for language bindings */
 	GtkDestroyNotify destroy_func;		/* Destroy notification function for language bindings */
 };
