@@ -266,8 +266,6 @@ libgnomeui_instance_init (GnomeProgram *program, GnomeModuleInfo *mod_info)
 static void
 libgnomeui_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info)
 {
-        gboolean ctype_set;
-        char *ctype, *old_ctype = NULL;
         gboolean do_crash_dialog = TRUE;
         const char *envar;
 
@@ -281,30 +279,6 @@ libgnomeui_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info)
 
         if(do_crash_dialog)
                 libgnomeui_segv_setup (app, FALSE);
-
-        /* Begin hack to propogate an en_US locale into Gtk+ if LC_CTYPE=C, so that non-ASCII
-           characters will display for as many people as possible. Related to bug #1979 */
-        ctype = setlocale (LC_CTYPE, NULL);
-
-        if (strcmp (ctype, "C") == 0) {
-                old_ctype = g_strdup (g_getenv ("LC_CTYPE"));
-                gnome_setenv ("LC_CTYPE", "en_US", TRUE);
-                ctype_set = TRUE;
-        } else {
-                ctype_set = FALSE;
-	}
-
-        gtk_set_locale ();
-
-        if (ctype_set) {
-                if (old_ctype) {
-			gnome_setenv ("LC_CTYPE", old_ctype, TRUE);
-                        g_free (old_ctype);
-                } else {
-			gnome_unsetenv ("LC_CTYPE");
-		}
-        }
-        /* End hack */
 }
 
 static gboolean
@@ -356,7 +330,7 @@ initialize_gtk_signal_relay (void)
 	if (!gnome_config_get_bool ("/sound/system/settings/event_sounds=true"))
 		return;
 	
-	ctmp = gnome_config_file ("/sound/events/gtk-events.soundlist");
+	ctmp = gnome_config_file ("/sound/events/gtk-events-2.soundlist");
 	ctmp2 = g_strconcat ("=", ctmp, "=", NULL);
 	g_free (ctmp);
 	iter_signames = gnome_config_init_iterator_sections (ctmp2);
@@ -420,7 +394,7 @@ initialize_gtk_signal_relay (void)
 static void
 libgnomeui_post_args_parse(GnomeProgram *program, GnomeModuleInfo *mod_info)
 {
-        GnomeProgramPrivate_libgnomeui *priv = g_new0(GnomeProgramPrivate_libgnomeui, 1);
+        GnomeProgramPrivate_libgnomeui *priv;
         gchar *filename;
 
         gnome_type_init();
@@ -432,8 +406,6 @@ libgnomeui_post_args_parse(GnomeProgram *program, GnomeModuleInfo *mod_info)
         priv = g_object_get_qdata(G_OBJECT(program), quark_gnome_program_private_libgnomeui);
         priv->constructed = TRUE;
 
-        _gnome_stock_icons_init ();
-
         /* load the accelerators */
         filename = g_build_filename (gnome_user_accels_dir_get (),
                                      gnome_program_get_app_id (program),
@@ -442,7 +414,12 @@ libgnomeui_post_args_parse(GnomeProgram *program, GnomeModuleInfo *mod_info)
         g_free (filename);
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMEUILOCALEDIR);
-	/*bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");*/
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
+
+        _gnome_stock_icons_init ();
+
 	initialize_gtk_signal_relay ();
 }
 
@@ -516,7 +493,7 @@ libgnomeui_rc_parse (GnomeProgram *program, const gchar *command)
 	/* <gnomedatadir>/gtkrc */
         file = gnome_program_locate_file (gnome_program_get (),
                                           GNOME_FILE_DOMAIN_DATADIR,
-                                          "gtkrc", TRUE, NULL);
+                                          "gtkrc-2.0", TRUE, NULL);
   	if (file) {
   		gtk_rc_add_default_file (file); 
 		g_free (file);
@@ -532,7 +509,7 @@ libgnomeui_rc_parse (GnomeProgram *program, const gchar *command)
         }
 	
 	/* ~/.gnome/gtkrc */
-	file = gnome_util_home_file("gtkrc");
+	file = gnome_util_home_file("gtkrc-2.0");
 	if (file) {
 		gtk_rc_add_default_file (file);
 		g_free (file);
